# py4Soundex

Soundex Python Library

## Getting Started

This project is simply implementation of Soundex algorithm in python programming language.

### Prerequisites

This Project Has No Prerequisites


### Installing

The easiest way to install py4Soundex is using pip

```
pip install py4Soundex
```

### Usage
It's only a function named Soundex. It takes string as argument and return soundex code
```
from py4Soundex.code import Soundex
print(Soundex('Smith'))
print(Soundex('Smyth'))
# Both Yield Same Code
```
